about summary refs log tree commit diff
diff options
context:
space:
mode:
authorPeter Jaszkowiak <p.jaszkow@gmail.com>2023-09-15 21:43:14 -0600
committerPeter Jaszkowiak <p.jaszkow@gmail.com>2023-09-16 10:46:53 -0600
commit09fd7a8722fb9634706dcd6ddb88473f4cc6bdf3 (patch)
treeedeca37c847f807bd44ff46db2743bfc97d36b2b
parent039875986ca5cb155c452e1d2e14e3afcf71aa8e (diff)
downloadrust-09fd7a8722fb9634706dcd6ddb88473f4cc6bdf3.tar.gz
rust-09fd7a8722fb9634706dcd6ddb88473f4cc6bdf3.zip
triagebot exclude_labels -> exclude_titles
-rw-r--r--src/tools/miri/.github/workflows/ci.yml2
-rw-r--r--src/tools/miri/miri-script/src/commands.rs4
-rw-r--r--src/tools/miri/triagebot.toml2
3 files changed, 4 insertions, 4 deletions
diff --git a/src/tools/miri/.github/workflows/ci.yml b/src/tools/miri/.github/workflows/ci.yml
index bcbd44a5f38..5e2abdde6ac 100644
--- a/src/tools/miri/.github/workflows/ci.yml
+++ b/src/tools/miri/.github/workflows/ci.yml
@@ -208,7 +208,7 @@ jobs:
           git push -u origin $BRANCH
       - name: Create Pull Request
         run: |
-          PR=$(gh pr create -B master --title 'Automatic sync from rustc' --body '' --label subtree-sync)
+          PR=$(gh pr create -B master --title 'Automatic sync from rustc' --body '')
           ~/.local/bin/zulip-send --user $ZULIP_BOT_EMAIL --api-key $ZULIP_API_TOKEN --site https://rust-lang.zulipchat.com \
             --stream miri --subject "Cron Job Failure (miri, $(date -u +%Y-%m))" \
             --message "A PR doing a rustc-pull [has been automatically created]($PR) for your convenience."
diff --git a/src/tools/miri/triagebot.toml b/src/tools/miri/triagebot.toml
index 69f3cd2f810..8d00cedb769 100644
--- a/src/tools/miri/triagebot.toml
+++ b/src/tools/miri/triagebot.toml
@@ -11,4 +11,4 @@ allow-unauthenticated = [
 [shortcut]
 
 [no-merges]
-exclude_labels = ["rollup", "subtree-sync"]
+exclude_titles = ["Rollup of", "sync from rustc"]
diff --git a/src/tools/miri/miri-script/src/commands.rs b/src/tools/miri/miri-script/src/commands.rs
index 124acc95098..de80777a689 100644
--- a/src/tools/miri/miri-script/src/commands.rs
+++ b/src/tools/miri/miri-script/src/commands.rs
@@ -339,9 +339,9 @@ impl Command {
             "Confirmed that the push round-trips back to Miri properly. Please create a rustc PR:"
         );
         println!(
             // Open PR with `subtree-sync` label to satisfy the `no-merges` triagebot check
             // See https://github.com/rust-lang/rust/pull/114157
-            "    https://github.com/rust-lang/rust/compare/{github_user}:{branch}?quick_pull=1&labels=subtree-sync"
+            "    https://github.com/rust-lang/rust/compare/{github_user}:{branch}?quick_pull=1&title=Miri+subtree+update"
         );
 
         drop(josh);
@@ -339,9 +339,9 @@ impl Command {
         );
         println!(
-            // Open PR with `subtree-sync` label to satisfy the `no-merges` triagebot check
+            // Open PR with `subtree update` title to silence the `no-merges` triagebot check
             // See https://github.com/rust-lang/rust/pull/114157